@@ -53,7 +53,6 @@ for which a new license (GPL+exception) is in place.
 #include "tocindexprefs.h"
 #include "undomanager.h"
 #include "units.h"
-#include "units.h"
 #include "util_icon.h"
 
 using namespace std;
@@ -88,7 +87,7 @@ Preferences::Preferences( QWidget* parent) : PrefsDialogBase( parent )
 	addItem( tr("Tools"), loadIcon("tools.png"), tabTools);
 
 	tabHyphenator = new HySettings(prefsWidgets/*, &ap->LangTransl*/);
-	addItem( tr("Hyphenator"), loadIcon("hyphenate.png"), tabHyphenator);
+	addItem( tr("Hyphenation and Spelling"), loadIcon("hyphenate.png"), tabHyphenator);
 
 	tabFonts = new FontPrefs(prefsWidgets, false, prefsManager->preferencesLocation(), ap->doc);
 	addItem( tr("Fonts"), loadIcon("font.png"), tabFonts);
@@ -299,18 +298,15 @@ void Preferences::setDS(int layout)
 
 void Preferences::unitChange()
 {
-	double oldUnitRatio = unitRatio;
 	docUnitIndex = tabDocument->unitCombo->currentIndex();
 	unitRatio = unitGetRatioFromIndex(docUnitIndex);
-	QString suffix = unitGetSuffixFromIndex(docUnitIndex);
-	double invUnitConversion = 1.0 / oldUnitRatio * unitRatio;
 	
 	tabDocument->unitChange();
-	tabGuides->unitChange(suffix, docUnitIndex, invUnitConversion);
+	tabGuides->unitChange(docUnitIndex);
 	tabView->unitChange(docUnitIndex);
 	tabTools->unitChange(docUnitIndex);
-	tabPDF->unitChange(suffix, docUnitIndex, invUnitConversion);
-	tabPrinter->unitChange(suffix, docUnitIndex, invUnitConversion);
+	tabPDF->unitChange(docUnitIndex);
+	tabPrinter->unitChange(docUnitIndex);
 }
 
 
@@ -433,7 +429,7 @@ void Preferences::updatePreferences()
 
 	prefsManager->appPrefs.guidesSettings.before = tabGuides->inBackground->isChecked();
 	
-	prefsManager->appPrefs.askBeforeSubstituite = tabMiscellaneous->AskForSubs->isChecked();
+	prefsManager->appPrefs.askBeforeSubstitute = tabMiscellaneous->AskForSubs->isChecked();
 	prefsManager->appPrefs.haveStylePreview = tabMiscellaneous->stylePreview->isChecked();
 	// lorem ipsum
 	prefsManager->appPrefs.useStandardLI = tabMiscellaneous->useStandardLI->isChecked();
